@@ -6,10 +6,11 @@ library(XML)
 library(tibble)
 library(purrr)
 
+biotech <- "drugbank_record_biotech.xml"
 test_that(desc = "Read database",
           code = {
             expect_true(get_xml_db_rows(
-              system.file("extdata", "drugbank_record.xml", package = "dbparser")
+              system.file("extdata", biotech, package = "dbparser")
             ))
           })
 
